@@ -77,6 +77,13 @@ class SurfingEntrance(object):
         Base.metadata.create_all(bind=ViewDatabaseConnector().get_engine())
         print('done')
 
+    def init_cas(self):
+        from .data.wrapper.cas.cas_init import sync_cas_table
+
+        print('Begin to create table for database: cas')
+        sync_cas_table()
+        print('done')
+
     def download_raw(self, yesterday=None):
         if not yesterday:
             yesterday = self._get_yesterday()
