@@ -113,11 +113,15 @@ class BasicDataApi(object):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundInfo.__tablename__}')
 
-    def get_fund_benchmark(self):
+    def get_fund_benchmark(self, fund_list: Tuple[str] = ()):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
-                        FundBenchmark
+                    FundBenchmark
+                )
+                if fund_list:
+                    query = query.filter(
+                        FundBenchmark.em_id.in_(fund_list),
                     )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
@@ -273,18 +277,21 @@ class BasicDataApi(object):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {IndexPrice.__tablename__}')
 
-    def get_index_price_dt(self,start_date, end_date):
+    def get_index_price_dt(self, start_date: str = '', end_date: str = ''):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                     IndexPrice
-                ).filter(
-                    IndexPrice.datetime >= start_date,
-                    IndexPrice.datetime <= end_date,
                 )
-                tag_df = pd.read_sql(query.statement, query.session.bind)
-                return tag_df
-
+                if start_date:
+                    query = query.filter(
+                        IndexPrice.datetime >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        IndexPrice.datetime <= end_date,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {IndexPrice.__tablename__}')
 
@@ -460,14 +467,16 @@ class BasicDataApi(object):
                 return pd.DataFrame([])
 
     @staticmethod
-    def get_fund_hold_asset_by_id(fund_id):
+    def get_fund_hold_asset_by_id(fund_id: str = ''):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                     FundHoldAsset,
-                ).filter(
-                    FundHoldAsset.fund_id == fund_id,
                 )
+                if fund_id:
+                    query = query.filter(
+                        FundHoldAsset.fund_id == fund_id,
+                    )
                 df = pd.read_sql(query.statement, query.session.bind)
                 return df
 
