@@ -159,6 +159,20 @@ class DerivedDataApi(object):
                 print(f'Failed to get data <err_msg> {e} from {IndexValuationLongTerm.__tablename__}')
                 return pd.DataFrame([])
 
+    def get_index_valuation_develop_columns_by_id(self, index_id, columns):
+        with DerivedDatabaseConnector().managed_session() as mn_session:
+            try:
+                query = mn_session.query(
+                    *columns
+                ).filter(
+                    IndexValuationLongTerm.index_id == index_id,
+                ).order_by(IndexValuationLongTerm.datetime.asc())
+                df = pd.read_sql(query.statement, query.session.bind)
+                return df
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {IndexValuationLongTerm.__tablename__}')
+                return pd.DataFrame([])
+
     def get_asset_allocation_info(self, version:int=2):
         with DerivedDatabaseConnector().managed_session() as mn_session:
             try:
@@ -187,7 +201,7 @@ class DerivedDataApi(object):
                 )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
-                print(f'Failed to get_style_factor_return {e} from {StyleAnalysisFactorReturn.__tablename__}')
+                print(f'Failed to get data <err_msg> {e} from {StyleAnalysisFactorReturn.__tablename__}')
                 return
 
     def get_barra_cne5_factor_return(self, start_date: str, end_date: str):
@@ -201,7 +215,7 @@ class DerivedDataApi(object):
                 )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
-                print(f'Failed to get_style_factor_return {e} from {StyleAnalysisFactorReturn.__tablename__}')
+                print(f'Failed to get data <err_msg> {e} from {StyleAnalysisFactorReturn.__tablename__}')
                 return
 
     def get_allocation_distribution(self, version:str=1):
@@ -215,6 +229,41 @@ class DerivedDataApi(object):
                 df = pd.read_sql(query.statement, query.session.bind)
                 return df
             except Exception as e:
-                print(f'Failed to get_style_factor_return {e} from {AllocationDistribution.__tablename__}')
+                print(f'Failed to get data <err_msg> {e} from {AllocationDistribution.__tablename__}')
                 return
 
+    def get_fund_manager_index(self, manager_id: Tuple[str] = (), start_date: str = '', end_date: str = '', fund_type: Tuple[str] = ()):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                query = session.query(
+                    FundManagerIndex
+                )
+                if manager_id:
+                    query = query.filter(FundManagerIndex.manager_id.in_(manager_id))
+                if start_date:
+                    query = query.filter(FundManagerIndex.datetime >= start_date)
+                if end_date:
+                    query = query.filter(FundManagerIndex.datetime <= end_date)
+                if fund_type:
+                    query = query.filter(FundManagerIndex.fund_type.in_(fund_type))
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {FundManagerIndex.__tablename__}')
+
+    def get_fund_manager_score(self, manager_id: Tuple[str] = (), start_date: str = '', end_date: str = '', fund_type: Tuple[str] = ()):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                query = session.query(
+                    FundManagerScore
+                )
+                if manager_id:
+                    query = query.filter(FundManagerScore.manager_id.in_(manager_id))
+                if start_date:
+                    query = query.filter(FundManagerScore.datetime >= start_date)
+                if end_date:
+                    query = query.filter(FundManagerScore.datetime <= end_date)
+                if fund_type:
+                    query = query.filter(FundManagerScore.fund_type.in_(fund_type))
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {FundManagerScore.__tablename__}')
