@@ -252,17 +252,31 @@ class RawDataApi:
                 print('Failed to get data <err_msg> {}'.format(e))
                 return None
 
-    def get_em_fund_nav(self, start_date, end_date):
+    def get_em_fund_nav(self, start_date: str = '', end_date: str = '', fund_ids: Tuple[str] = (), columns: Tuple[str] = ()):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
-                query = db_session.query(
-                    EmFundNav
-                ).filter(
-                    EmFundNav.DATES >= start_date,
-                    EmFundNav.DATES <= end_date,
-                )
-                df = pd.read_sql(query.statement, query.session.bind)
-                return df
+                if not columns:
+                    query = db_session.query(
+                        EmFundNav
+                    )
+                else:
+                    query = db_session.query(
+                        EmFundNav.CODES,
+                        EmFundNav.DATES,
+                    ).add_columns(*columns)
+                if fund_ids:
+                    query = query.filter(
+                        EmFundNav.CODES.in_(fund_ids),
+                    )
+                if start_date:
+                    query = query.filter(
+                        EmFundNav.DATES >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        EmFundNav.DATES <= end_date,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {EmFundNav.__tablename__}')
                 return None
@@ -736,6 +750,23 @@ class RawDataApi:
                 print(f'Failed to get data <err_msg> {e} from {WindFundStockPortfolio.__tablename__}')
                 return None
 
+    def get_wind_fund_bond_portfolio(self, start_date: str, end_date: str, wind_fund_list: Tuple[str] = ()):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    WindFundBondPortfolio
+                ).filter(
+                    WindFundBondPortfolio.F_PRT_ENDDATE >= start_date,
+                    WindFundBondPortfolio.F_PRT_ENDDATE <= end_date,
+                )
+                if wind_fund_list:
+                    query = query.filter(
+                        WindFundBondPortfolio.S_INFO_WINDCODE.in_(wind_fund_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {WindFundBondPortfolio.__tablename__}')
+
     def get_wind_fund_nav(self, start_date: str, wind_fund_list:list):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
@@ -751,16 +782,23 @@ class RawDataApi:
                 print(f'Failed to get data <err_msg> {e} from {WindFundNav.__tablename__}')
                 return None
 
-    def get_wind_manager_info(self, wind_fund_list:list):
+    def get_wind_manager_info(self, wind_fund_list: List[str] = '', columns: Tuple[str] = ()):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
-                query = db_session.query(
-                    WindFundManager
-                ).filter(
-                    WindFundManager.F_INFO_WINDCODE.in_(wind_fund_list),
-                )
-                df = pd.read_sql(query.statement, query.session.bind)
-                return df
+                if not columns:
+                    query = db_session.query(
+                        WindFundManager
+                    )
+                else:
+                    query = db_session.query(
+                        WindFundManager.F_INFO_FUNDMANAGER_ID,
+                        WindFundManager.F_INFO_WINDCODE,
+                    ).add_columns(*columns)
+                if wind_fund_list:
+                    query = query.filter(
+                        WindFundManager.F_INFO_WINDCODE.in_(wind_fund_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {WindFundManager.__tablename__}')
                 return None
@@ -794,10 +832,14 @@ class RawDataApi:
                 print(f'Failed to get data <err_msg> {e} from {EMFundRate.__tablename__}')
                 return None
 
-    def get_em_fund_hold_asset(self, start_date: str = '', end_date: str = ''):
+    def get_em_fund_hold_asset(self, start_date: str = '', end_date: str = '', fund_ids: Tuple[str] = ()):
         with RawDatabaseConnector().managed_session() as raw_session:
             try:
                 query = raw_session.query(EMFundHoldAsset)
+                if fund_ids:
+                    query = query.filter(
+                        EMFundHoldAsset.CODES.in_(fund_ids),
+                    )
                 if start_date:
                     query = query.filter(
                         EMFundHoldAsset.DATES >= start_date,
@@ -811,23 +853,31 @@ class RawDataApi:
                 print(f'Failed to get data <err_msg> {e} from {EMFundHoldAsset.__tablename__}')
                 return None
 
-    def get_em_fund_hold_industry(self, end_date: str = ''):
+    def get_em_fund_hold_industry(self, end_date: str = '', fund_ids: Tuple[str] = ()):
         with RawDatabaseConnector().managed_session() as raw_session:
             try:
                 query = raw_session.query(EMFundHoldIndustry)
+                if fund_ids:
+                    query = query.filter(
+                        EMFundHoldIndustry.CODES.in_(fund_ids),
+                    )
                 if end_date:
                     query = query.filter(
-                        EMFundHoldIndustry.DATES <= end_date
+                        EMFundHoldIndustry.DATES <= end_date,
                     )
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {EMFundHoldIndustry.__tablename__}')
                 return None
 
-    def get_em_fund_hold_stock(self, end_date: str = ''):
+    def get_em_fund_hold_stock(self, end_date: str = '', fund_ids: Tuple[str] = ()):
         with RawDatabaseConnector().managed_session() as raw_session:
             try:
                 query = raw_session.query(EMFundHoldStock)
+                if fund_ids:
+                    query = query.filter(
+                        EMFundHoldStock.CODES.in_(fund_ids),
+                    )
                 if end_date:
                     query = query.filter(
                         EMFundHoldStock.DATES <= end_date
@@ -837,10 +887,14 @@ class RawDataApi:
                 print(f'Failed to get data <err_msg> {e} from {EMFundHoldStock.__tablename__}')
                 return None
 
-    def get_em_fund_hold_bond(self, end_date: str = ''):
+    def get_em_fund_hold_bond(self, end_date: str = '', fund_ids: Tuple[str] = ()):
         with RawDatabaseConnector().managed_session() as raw_session:
             try:
                 query = raw_session.query(EMFundHoldBond)
+                if fund_ids:
+                    query = query.filter(
+                        EMFundHoldBond.CODES.in_(fund_ids),
+                    )
                 if end_date:
                     query = query.filter(
                         EMFundHoldBond.DATES <= end_date
@@ -850,27 +904,31 @@ class RawDataApi:
                 print('Failed to get data <err_msg> {}'.format(e))
                 return None
 
-    def get_em_mng_info(self):
+    def get_em_mng_info(self, fund_ids: Tuple[str] = ()):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                     EMMngInfo
                 )
-                df = pd.read_sql(query.statement, query.session.bind)
-                return df
-
+                if fund_ids:
+                    query = query.filter(
+                        EMMngInfo.code.in_(fund_ids),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print('Failed to get data <err_msg> {}'.format(e))
 
-    def get_em_fund_mng_change(self):
+    def get_em_fund_mng_change(self, fund_ids: Tuple[str] = ()):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                     EMFundMngChange
                 )
-                df = pd.read_sql(query.statement, query.session.bind)
-                return df
-
+                if fund_ids:
+                    query = query.filter(
+                        EMFundMngChange.code.in_(fund_ids),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print('Failed to get data <err_msg> {}'.format(e))
 
@@ -886,15 +944,17 @@ class RawDataApi:
             except Exception as e:
                 print('Failed to get data <err_msg> {}'.format(e))
 
-    def get_em_fund_com_core_mng(self):
+    def get_em_fund_com_core_mng(self, fund_ids: Tuple[str] = ()):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                     EMFundCompCoreMng
                 )
-                df = pd.read_sql(query.statement, query.session.bind)
-                return df
-
+                if fund_ids:
+                    query = query.filter(
+                        EMFundCompCoreMng.code.in_(fund_ids),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print('Failed to get data <err_msg> {}'.format(e))
 
@@ -910,6 +970,14 @@ class RawDataApi:
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {EmStockDividend.__tablename__}')
 
+    def get_em_bond_info(self):
+        with RawDatabaseConnector().managed_session() as raw_session:
+            try:
+                query = raw_session.query(EmBondInfo)
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get data <err_msg> {e} from {EmBondInfo.__tablename__}')
+
     def get_em_bond_rating(self, end_date: str = ''):
         with RawDatabaseConnector().managed_session() as raw_session:
             try:
