@@ -4,12 +4,14 @@ import traceback
 import json
 import numpy as np
 import pandas as pd
-from typing import List, Dict, Optional, Tuple, Union
+from typing import List, Dict, Optional, Tuple, Union, Set
 
-from ....constant import SectorType, IndexPriceSource, INDEX_PRICE_EXTRA_TRADE_DAYS
+from ....constant import SectorType, IndexPriceSource, INDEX_PRICE_EXTRA_TRADE_DAYS, FUND_NAV_EXTRA_TRADE_DAYS
 from ...api.raw import RawDataApi
 from ...api.basic import BasicDataApi
 from ...view.basic_models import *
+from ...manager.fund_tag_update import fund_tag
+# from ..raw.raw_data_helper import RawDataHelper
 from .basic_data_helper import BasicDataHelper
 
 
@@ -93,6 +95,135 @@ class BasicDataPart1:
         wind_fund_info['track_index'] = wind_fund_info['track_index'].map(lambda x: dic.get(x,'none'))
         self._data_helper._upload_basic(wind_fund_info, FundInfo.__table__.name)
 
+    def fund_info_from_raw(self, fund_id_list: Set[str], benchmark_profile: pd.Series):
+        def _invest_type_class_to_wind_class_1(x: pd.Series) -> str:
+            if x.invest_type_class == '其他基金':
+                if 'QDII' in x.desc_name:
+                    return '国际(QDII)基金'
+            return x.invest_type_class
+
+        def _invest_type_class_to_wind_class_2(invest_type_class: str) -> str:
+            '''Choice的基金二级类型转换为wind的'''
+
+            if invest_type_class == '混合债券型基金（一级）':
+                return '混合债券型一级基金'
+            elif invest_type_class == '长期纯债型基金':
+                return '中长期纯债型基金'
+            elif invest_type_class == '中短期纯债型基金':
+                return '短期纯债型基金'
+            elif invest_type_class == '混合债券型基金（二级）':
+                return '混合债券型二级基金'
+            elif invest_type_class in ('QDII基金', '封闭式基金', '保本型基金'):
+                # error case
+                return
+            else:
+                return invest_type_class
+
+        def _lambda_structure_type(x: pd.Series) -> int:
+            if x.base_fund_id is None:
+                return 0
+            if x.base_fund_id == x.wind_id:
+                return 1
+            # 到这里应该必然是分级基金，所以直接判断A,B即可
+            elif 'A' in x.desc_name:
+                return 2
+            elif 'B' in x.desc_name:
+                return 3
+            else:
+                # 分级基金A,B份额可能名字里不带A,B，之后需要手工修改下
+                return 4
+
+        def _lambda_index_id_new(x: pd.Series, benchmark: pd.DataFrame) -> Optional[str]:
+            try:
+                return fund_tag(x.base_fund_id, x.desc_name, x.is_open, x.currency, x.wind_class_2, benchmark.at[x.wind_id, 'benchmark_s_raw'], x.fund_id)
+            except KeyError:
+                print(f'{x.fund_id} has no benchmark info')
+                return
+
+        def _lambda_fund_manager(x: str) -> pd.Series:
+            manager_list: List[str] = x.split(',')
+            return pd.Series(['\r\n'.join(manager_list), manager_list[0]])
+
+        def _lambda_benchmark(x: str) -> pd.Series:
+            def _parse_index(part: str):
+                if '×' in part:
+                    es = part.split('×')
+                elif '*' in part:
+                    es = part.split('*')
+                elif '╳' in part:
+                    es = part.split('╳')
+                else:
+                    return part
+
+                if '%' in es[0]:
+                    return es[1]
+                else:
+                    return es[0]
+
+            if x is None:
+                return
+            benchmarks: List[str] = x.split('+')
+            if len(benchmarks) == 1:
+                second = None
+            else:
+                second = _parse_index(benchmarks[1])
+            return pd.Series([_parse_index(benchmarks[0]), second])
+
+        def _lambda_fee(x: str, em_fund_fee: pd.DataFrame) -> pd.Series:
+            def _parse_fee(fee: str):
+                if fee is None:
+                    return
+                cheapest_fee = fee.split(';')[0]
+                es = cheapest_fee.split(':')
+                if len(es) > 1:
+                    value = es[1]
+                else:
+                    value = es[0]
+                if value[-1] == '%':
+                    value = float(value[:-1]) / 100
+                else:
+                    try:
+                        value = float(value) / 100
+                    except ValueError:
+                        return
+                return value
+
+            fee = em_fund_fee.loc[x, ['manage_fee', 'trustee_fee', 'purchase_fee', 'redeem_fee']]
+            return fee.transform(_parse_fee)
+
+        # 只处理非场内基金
+        fund_id_list = [one for one in fund_id_list if '.OF' in one]
+        # 获取raw中的基金基础信息
+        df = self._raw_data_api.get_em_fund_info(fund_id_list).drop(columns='_update_time')
+        # 其中一部分列可以直接使用，改一下名字即可
+        df = df.rename(columns={'em_id': 'wind_id', 'name': 'desc_name', 'manager_id': 'pre_fund_manager'})
+        # 没有end_date的话给一个默认值
+        df['end_date'] = df['end_date'].where(df.end_date.notna(), '2040-12-31')
+        # 这里可能还需要加上港币
+        df['currency'] = df.currency.map({'人民币元': 'CNY', '美元': 'USD'})
+        # 基金经理
+        df[['manager_id', 'fund_manager']] = df.pre_fund_manager.apply(_lambda_fund_manager)
+        # 新基金都是!0，这里需要检查是否有相同order_book_id的旧基金
+        df['order_book_id'] = df.wind_id.transform(lambda x: x.split('.')[0])
+        df['transition'] = 0
+        df['fund_id'] = df.order_book_id.transform(lambda x: x + '!0')
+        # Choice的基金一二级分类转换为wind的
+        df['wind_class_1'] = df[['desc_name', 'invest_type_class_2']].transform(_invest_type_class_to_wind_class_1, axis=1)
+        df['wind_class_2'] = df.invest_type_class_2.transform(_invest_type_class_to_wind_class_2)
+        df['asset_type'] = df.apply(lambda x: self._find_tag(x.desc_name, x.wind_class_2), axis=1)
+        df['structure_type'] = df.apply(_lambda_structure_type, axis=1)
+        df['is_etf'] = df.desc_name.transform(lambda x: 1 if ('ETF' in x and '联接' not in x) else 0)
+        fund_benchmark = self._basic_data_api.get_fund_benchmark(fund_id_list).set_index('em_id')
+        df['index_id_new'] = df.apply(_lambda_index_id_new, axis=1, benchmark=fund_benchmark)
+        em_fund_fee = self._raw_data_api.get_em_fund_fee(fund_id_list).drop(columns='_update_time').set_index('em_id')
+        df[['manage_fee', 'trustee_fee', 'purchase_fee', 'redeem_fee']] = df.wind_id.transform(_lambda_fee, em_fund_fee=em_fund_fee)
+        df = df.set_index('wind_id').join(em_fund_fee[['subscr_fee', 'purchase_fee', 'redeem_fee', 'service_fee']].rename(columns={'subscr_fee': 'subscr_fee_detail', 'purchase_fee': 'purchase_fee_detail', 'redeem_fee': 'redeem_fee_detail'}))
+        df['benchmark'] = benchmark_profile
+        # 拆解上边的benchmark
+        df[['benchmark_1', 'benchmark_2']] = df.benchmark.apply(_lambda_benchmark)
+        df = df.drop(columns='invest_type_class_2').reset_index()
+        self._data_helper._upload_basic(df, FundInfo.__table__.name)
+
     def index_info(self):
         # Update manually
         # Not verified
@@ -113,42 +244,40 @@ class BasicDataPart1:
         df['index_id'] = index_ids
         self._data_helper._upload_basic(df, IndexInfo.__table__.name)
 
-    @staticmethod
-    def _lambda_func_index_component_2(em_id_to_index_id: Dict[str, str], x: str):
-        info = json.loads(x)
-        r = []
-        for one in info:
-            em_id = one[0]
-            if em_id in ['000915.SH', '000916.SH']:
-                em_id = em_id.split('.')[0] + '.CSI'
-            r.append((em_id_to_index_id[em_id], one[1]))
-        return json.dumps(r)
-
-    @staticmethod
-    def _lambda_func_index_component_3(wind_id_to_id: Dict[str, str], x: str):
-        if x is None:
-            return x
-        r = []
-        info = json.loads(x)
-        for one in info:
-            try:
-                r.append(wind_id_to_id[one + '.OF'])
-            except KeyError:
-                r.append(one + '!0')
-        return json.dumps(r)
-
     def index_component(self):
+        def _lambda_func_index_component_2(em_id_to_index_id: Dict[str, str], x: str):
+            info = json.loads(x)
+            r = []
+            for one in info:
+                em_id = one[0]
+                if em_id in ['000915.SH', '000916.SH']:
+                    em_id = em_id.split('.')[0] + '.CSI'
+                r.append((em_id_to_index_id[em_id], one[1]))
+            return json.dumps(r)
+
+        def _lambda_func_index_component_3(wind_id_to_id: Dict[str, str], x: str):
+            if x is None:
+                return x
+            r = []
+            info = json.loads(x)
+            for one in info:
+                try:
+                    r.append(wind_id_to_id[one + '.OF'])
+                except KeyError:
+                    r.append(one + '!0')
+            return json.dumps(r)
+
         index_info_df = self._index_info_df[self._index_info_df.em_id.notna()]
         index_info_df = index_info_df.set_index('em_id')
         em_id_to_index_id: Dict[str, str] = index_info_df['index_id'].to_dict()
 
         df = self._raw_data_api.get_cs_index_component().drop(columns=['_update_time'])
         df['index_id'] = df['index_id'].map(em_id_to_index_id)
-        df['sector'] = df['sector'].transform(lambda x: BasicDataPart1._lambda_func_index_component_2(em_id_to_index_id, x))
+        df['sector'] = df['sector'].transform(lambda x: _lambda_func_index_component_2(em_id_to_index_id, x))
         df['id_cat'] = df['id_cat'].transform(lambda x: x.name)
         fund_info_df = self._fund_info_df.set_index('wind_id')
         wind_id_to_id: Dict[str, str] = fund_info_df['fund_id'].to_dict()
-        df['related_funds'] = df['related_funds'].transform(lambda x: BasicDataPart1._lambda_func_index_component_3(wind_id_to_id, x))
+        df['related_funds'] = df['related_funds'].transform(lambda x: _lambda_func_index_component_3(wind_id_to_id, x))
         self._data_helper._upload_basic(df, IndexComponent.__table__.name)
 
     def fund_nav_from_rq(self, start_date, end_date):
@@ -162,10 +291,21 @@ class BasicDataPart1:
 
     def fund_nav(self, start_date, end_date):
         try:
-            start_date = datetime.datetime.strptime(start_date, '%Y%m%d') - datetime.timedelta(days=5)
-            del_date = start_date + datetime.timedelta(days=1)
-            start_date = start_date.strftime('%Y%m%d')
-            df = self._raw_data_api.get_em_fund_nav(start_date, end_date)
+            raw_start_date_dt: datetime.date = pd.to_datetime(start_date, infer_datetime_format=True).date()
+            end_date = pd.to_datetime(end_date, infer_datetime_format=True).date()
+
+            # 多取N个交易日的数据
+            start_date = raw_start_date_dt - datetime.timedelta(days=40)
+            trading_day_df = BasicDataApi().get_trading_day_list(start_date, end_date)
+            trading_day_df = trading_day_df[trading_day_df.datetime <= raw_start_date_dt]
+            assert trading_day_df.datetime.size >= FUND_NAV_EXTRA_TRADE_DAYS, f'should at least have {FUND_NAV_EXTRA_TRADE_DAYS} trading days'
+            # del_date在start_date后边一天，确保可以正确计算ret等daily difference
+            start_date = trading_day_df.datetime.array[-FUND_NAV_EXTRA_TRADE_DAYS]
+            del_date = trading_day_df.datetime.array[-(FUND_NAV_EXTRA_TRADE_DAYS-1)]
+            print(f'[fund_nav] (start_date){start_date} (del_date){del_date} (end_date){end_date}')
+
+            # start_date = start_date.strftime('%Y%m%d')
+            df = self._raw_data_api.get_em_fund_nav(start_date, end_date).drop(columns='_update_time')
             df['fund_id'] = df.apply(
                 lambda x: self._data_helper._get_fund_id_from_order_book_id(x['CODES'].split('.')[0], x['DATES']), axis=1)
             df = df.drop(['CODES'], axis=1)
@@ -184,9 +324,9 @@ class BasicDataPart1:
             df = df.set_index(['datetime', 'fund_id'])
             df['change_rate'] = (anv_df / anv_df.shift(1) - 1).stack()
 
-            end_date = datetime.datetime.strptime(end_date, '%Y%m%d').date()
+            df = df[df.index.get_level_values(level='datetime').date >= del_date]
+            # TODO: 最好应该原子提交下边两步
             BasicDataApi().delete_fund_nav(del_date, end_date)
-            df = df[df.index.get_level_values(level='datetime').date >= del_date.date()]
             self._data_helper._upload_basic(df.reset_index(), FundNav.__table__.name)
             return True
         except Exception as e:
@@ -203,9 +343,8 @@ class BasicDataPart1:
         try:
             raw_start_date_dt: datetime.date = pd.to_datetime(start_date, infer_datetime_format=True).date()
             # 多取N个交易日的数据
-            start_date = datetime.datetime.strptime(start_date, '%Y%m%d') - datetime.timedelta(days=90)
-            start_date = start_date.strftime('%Y%m%d')
-            trading_day_df = BasicDataApi().get_trading_day_list(start_date, end_date)
+            start_date = raw_start_date_dt - datetime.timedelta(days=90)
+            trading_day_df = BasicDataApi().get_trading_day_list(start_date.start_date.strftime('%Y%m%d'), end_date)
             trading_day_df = trading_day_df[trading_day_df.datetime <= raw_start_date_dt]
             assert trading_day_df.datetime.size >= INDEX_PRICE_EXTRA_TRADE_DAYS, f'should at least have {INDEX_PRICE_EXTRA_TRADE_DAYS} trading days'
             # del_date在start_date后边一天，确保可以正确计算ret等daily difference
@@ -231,16 +370,40 @@ class BasicDataPart1:
                 df_list.append(df)
                 if not df.empty:
                     index_id_list.append(index_id)
+                # if em_id == 'SPX.GI':
+                #     df['index_id'] = 'sp500'
+                #     df_list.append(df.copy())
+                #     if not df.empty:
+                #         index_id_list.append('sp500')
+
+                #     df = df.set_index('datetime').join(cm_index_price[['usd_central_parity_rate']])
+                #     df['index_id'] = 'sp500rmb'
+                #     df['open'] *= df['usd_central_parity_rate']
+                #     df['close'] *= df['usd_central_parity_rate']
+                #     df['low'] *= df['usd_central_parity_rate']
+                #     df['high'] *= df['usd_central_parity_rate']
+                #     df['ret'] = df.close / df.close.shift(1) - 1
+                #     df = df.copy().reset_index().drop('usd_central_parity_rate', axis=1)
+                #     df_list.append(df.copy())
+                #     if not df.empty:
+                #         index_id_list.append('sp500rmb')
+                # else:
+                #     df_list.append(df)
+                #     if not df.empty:
+                #         index_id_list.append(index_id)
 
             end_date_dt: datetime.date = pd.to_datetime(end_date, infer_datetime_format=True).date()
-            index_list = ['sp500', 'dax30', 'n225']
-            cm_index_list = ['sp500rmb', 'dax30rmb', 'n225rmb']
+            index_list = ['sp500']  #, 'dax30', 'n225']
+            cm_index_list = ['sp500rmb']  #, 'dax30rmb', 'n225rmb']
             for i, c in zip(index_list, cm_index_list):
                 df = yahoo_index_price[yahoo_index_price['index_id'] == i]
                 df = df.set_index('datetime').reindex(cm_index_price.index).fillna(method='ffill')
                 # 存进去人民币计价的数据
+                df = df[['close', 'open', 'low', 'high', 'volume']]
                 df['close'] *= cm_index_price['usd_central_parity_rate']
-                df = df[['close']]
+                df['open'] *= cm_index_price['usd_central_parity_rate']
+                df['low'] *= cm_index_price['usd_central_parity_rate']
+                df['high'] *= cm_index_price['usd_central_parity_rate']
                 df['index_id'] = c
                 df['ret'] = df.close / df.close.shift(1) - 1
                 df = df.loc[raw_start_date_dt:end_date_dt, :]
@@ -354,13 +517,6 @@ class BasicDataPart1:
             traceback.print_exc()
             return False
 
-    @staticmethod
-    def _lambda_func_index_component_1(em_id_map: Dict[str, str], x: str):
-        try:
-            return em_id_map[x]
-        except KeyError:
-            return x
-
     def sector_info(self):
         try:
             df = pd.read_csv('./data/sector_info.csv', index_col=0)
@@ -373,6 +529,12 @@ class BasicDataPart1:
             return False
 
     def sector_funds(self):
+        def _lambda_sector_funds_1(em_id_map: Dict[str, str], x: str):
+            try:
+                return em_id_map[x]
+            except KeyError:
+                return x
+
         try:
             index_info_df = self._index_info_df[self._index_info_df.em_id.notna()]
             index_info_df = index_info_df.set_index('em_id')
@@ -380,7 +542,7 @@ class BasicDataPart1:
             em_id_to_index_id: Dict[str, str] = index_info_df['index_id'].to_dict()
 
             df = pd.read_csv('./data/sector_funds.csv', index_col=0)
-            df['csi_index_id'] = df['csi_index_id'].transform(lambda x: BasicDataPart1._lambda_func_index_component_1({em_id.split('.')[0]: em_id for em_id in em_id_list if em_id is not None}, x))
+            df['csi_index_id'] = df['csi_index_id'].transform(lambda x: _lambda_sector_funds_1({em_id.split('.')[0]: em_id for em_id in em_id_list if em_id is not None}, x))
             df['index_id'] = df['csi_index_id'].map(em_id_to_index_id)
             self._data_helper._upload_basic(df, SectorFunds.__table__.name, to_truncate=True)
             return True
@@ -671,6 +833,13 @@ class BasicDataPart1:
         if not self.index_price(start_date, end_date):
             failed_tasks.append('index_price')
 
+        # new_fund_list, _ = RawDataHelper.get_new_and_delisted_fund_list(end_date)
+        # if new_fund_list is None:
+        #     failed_tasks.append('get new_fund_list')
+        # else:
+        #     if not self.fund_info_from_raw(new_fund_list):
+        #         failed_tasks.append('fund_info')
+
         # TODO: Depend on RQ, change to EM
         if not self.fund_rating_latest():
             failed_tasks.append('fund_rating_latest')
