@@ -31,7 +31,7 @@ class BasicFundRet(BasicDataPart1):
         with BasicDatabaseConnector().managed_session() as quant_session:
             query = quant_session.query(TradingDayList)
             trading_days = pd.read_sql(query.statement, query.session.bind).drop(columns='_update_time')
-        
+
         self.start_date = start_date if isinstance(start_date, datetime.date) else datetime.datetime.strptime(start_date,'%Y%m%d').date()
         self.end_date = end_date if isinstance(end_date, datetime.date) else datetime.datetime.strptime(end_date,'%Y%m%d').date()
         dts = trading_days.datetime
@@ -109,8 +109,9 @@ class BasicFundRet(BasicDataPart1):
             self.res.append(df)
         self.result = pd.concat(self.res, axis=1, sort=True).reset_index().rename(columns={'index':'fund_id'})
         self.result['datetime'] = self.fund_nav.index[-1]
-        self.result['info_ratio'] = None # TODO
-        self.result = self.result.replace(np.inf,None).replace(-np.inf,None)
+        self.result['info_ratio'] = None  # TODO
+        self.result = self.result.replace({np.inf: None, -np.inf: None})
+        self.result = self.result[self.result.drop(columns=['fund_id', 'datetime']).notna().any(axis=1)]
 
     def process_all(self, end_date):
         failed_tasks = []
@@ -119,10 +120,9 @@ class BasicFundRet(BasicDataPart1):
             self.init(default_begin_date, end_date)
             self.calculate_one_date()
             self._data_helper._upload_basic(self.result, FundRet.__table__.name)
-
         except Exception as e:
             print(e)
             traceback.print_exc()
             failed_tasks.append('fund_score')
 
-        return failed_tasks
\ No newline at end of file
+        return failed_tasks
