@@ -1,7 +1,9 @@
-
+#import sys
+#sys.path.append("/Users/puyuantech/Documents/GitHub/surfing/python")
 from typing import List, Dict
 import pandas as pd
 import numpy as np
+import math
 import datetime
 import traceback
 import json
@@ -11,14 +13,17 @@ from scipy.optimize import Bounds, minimize
 from statsmodels.tsa.ar_model import AutoReg
 from ...api.basic import BasicDataApi
 from ...view.derived_models import FundIndicatorGroup
+#from surfing.data.api.basic import BasicDataApi
+#from surfing.data.view.derived_models import FundIndicatorGroup
 
 
 class FundIndicatorProcessorGroup:
 
     _TRADING_DAYS_PER_YEAR = 242
     _NATURAL_DAYS_PER_YEAR = 365
-    _RISK_FEE_RATE = 0.025
+    _RISK_FEE_RATE = 0.011
     _RISK_FEE_RATE_PER_DAY = _RISK_FEE_RATE / _TRADING_DAYS_PER_YEAR
+    _REPORT_DATE_LIST = [ '0331','0630', '0930','1231']
 
     def __init__(self, data_helper):
         self._data_helper = data_helper
@@ -84,6 +89,39 @@ class FundIndicatorProcessorGroup:
         self._wind_class_1: np.ndarray = fund_list.wind_class_1.unique()
         # 按wind二级分类计算分类呢基金收益率排名
         self._get_continue_stats_tool()
+        # 取出沪深300收益率
+        self._hs300 = self._basic_api.get_index_price(tuple(['hs300']))[['datetime','close']]
+        self._hs300 = self._hs300.set_index(self._hs300.datetime)['close']
+        self._hs300 = self._hs300.apply(np.log).diff()[1:]
+        # 取出货币基金指数收益率
+        self._mmf = self._basic_api.get_index_price(tuple(['mmf']))[['datetime','close']]
+        self._mmf = self._mmf.set_index(self._mmf.datetime)['close']
+        self._mmf = self._mmf.apply(np.log).diff()[1:]
+        # 获取年报/半年报的发布日期
+        end_date_dt = pd.to_datetime(end_date, infer_datetime_format=True)
+        md = end_date_dt.strftime('%m%d')
+        sentry_date = pd.Series(self._REPORT_DATE_LIST)
+        sentry = sentry_date[sentry_date <= md]
+        # 为半年报/年报发布预留一个季度的缓冲时间
+        if sentry.empty:
+            real_date = datetime.date(end_date_dt.year - 1, 6, 30)
+        elif len(sentry) <= 2:
+            real_date = datetime.date(end_date_dt.year - 1, 12, 31)
+        else:
+            real_date = datetime.date(end_date_dt.year, 6, 30)
+          
+        # 取出持仓数据      
+        self._fund_hold = self._basic_api.get_history_fund_size()
+        self._fund_hold = self._fund_hold[self._fund_hold.datetime == real_date][['fund_id','institution_holds','hold_num']].reset_index()
+        if sentry.empty:  
+            real_date_2 = datetime.date(end_date_dt.year - 1, 12, 31)
+        else:
+            real_date_2 = pd.to_datetime(str(end_date_dt.year)+sentry.array[-1], infer_datetime_format=True).date()
+        # 取出货基风险相关数据
+        self._risk_metric = self._basic_api.get_fund_hold_asset_by_id()
+        self._risk_metric = self._risk_metric[self._risk_metric.datetime == real_date][['fund_id','first_repo_to_nav','avg_ptm']].reset_index()
+
+        
 
     def df_resample(self, df):
         df.index = pd.to_datetime(df.index)
@@ -99,7 +137,7 @@ class FundIndicatorProcessorGroup:
         if result.success:
             information_statistic = -result.fun
             if information_statistic <= 0:
-                return np.nan
+                return 0
             stutzer_index = np.abs(np.mean(ex_return)) / np.mean(ex_return) * np.sqrt(2 * information_statistic)
             # result = {'information_statistic': information_statistic,
             #         'stutzer_index': stutzer_index,
@@ -306,11 +344,25 @@ class FundIndicatorProcessorGroup:
         df_i = df_i[(~np.isnan(df_i)).all(axis=1)]
         df_i = df_i[-self._TRADING_DAYS_PER_YEAR:]
 
+        df_i_hs300: np.ndarray = self._fund_ret[[fund_id]].join(self._hs300, rsuffix='_b').to_numpy()
+        df_i_hs300 = df_i_hs300[(~np.isnan(df_i_hs300)).all(axis=1)]
+        df_i_hs300 = df_i_hs300[-self._TRADING_DAYS_PER_YEAR:]
+
+        df_i_mmf: np.ndarray = self._fund_ret[[fund_id]].join(self._mmf, rsuffix='_b').to_numpy()
+        df_i_mmf = df_i_mmf[(~np.isnan(df_i_mmf)).all(axis=1)]
+        df_i_mmf = df_i_mmf[-self._TRADING_DAYS_PER_YEAR:]
+
+
         # alpha, beta
         alpha, beta = self._lambda_alpha_beta(df_i)
-        # mdd
+        # alpha, beta to the market
+        alpha_hs300, beta_hs300 = self._lambda_alpha_beta(df_i_hs300)
+        # mdd & len(mdd)
         mdd_part = sr / sr.cummax()
         mdd = 1 - mdd_part.min()
+        mdd_date2 = mdd_part.idxmin()
+        mdd_date1 = sr[:mdd_date2].idxmax()
+        mdd_len = (mdd_date2 - mdd_date1).days
         # sharpe ratio
         annual_vol = (sr / sr.shift(1)).std(ddof=1) * np.sqrt(self._TRADING_DAYS_PER_YEAR)
         annual_ret = np.exp(np.log(sr.iloc[-1] / sr.fillna(method='bfill').iloc[0]) / sr.shape[0] * self._TRADING_DAYS_PER_YEAR) - 1
@@ -324,12 +376,46 @@ class FundIndicatorProcessorGroup:
         calma_ratio = annual_ret / mdd if mdd != 0 else np.nan
         # ex return
         _ex_return = df_i[:, 0] - df_i[:, 1]
+        # excess return against hs300
+        _ex_return_hs300 = df_i_hs300[:, 0] - df_i_hs300[:, 1]
+        # excess return against mmf
+        _ex_return_mmf = df_i_mmf[:, 0] - df_i_mmf[:, 1]
+        # winning rate against mmf
+        winning_rate = len(_ex_return_mmf[_ex_return_mmf>0])/len(_ex_return_mmf)
         # track error
         track_err = np.nanstd(_ex_return, ddof=1) * np.sqrt(self._TRADING_DAYS_PER_YEAR)
+        # track error agains hs300
+        track_err_hs300 = np.nanstd(_ex_return_hs300, ddof=1) * np.sqrt(self._TRADING_DAYS_PER_YEAR)
         # information error
         info_ratio = alpha / track_err
+        # information ratio against hs300
+        info_ratio_hs300 = alpha_hs300 / track_err_hs300
         # scale
         scale = self.get_scale(self.end_date, fund_id)
+        # VaR
+        ret = df_i[:, 0]
+        VaR = np.quantile(ret, 0.05)
+        CVaR = ret[ret<=VaR].mean()
+        # institution holds & hold_num
+        if fund_id in self._fund_hold.fund_id.values:
+            temp_hold = self._fund_hold[self._fund_hold.fund_id == fund_id]
+            ins_holds = temp_hold.institution_holds.values[0]
+            hold_num = temp_hold.hold_num.values[0]
+        else:
+            ins_holds = np.nan
+            hold_num = np.nan
+        #
+        if fund_id in self._risk_metric.fund_id.values:
+            temp_risk = self._risk_metric[self._risk_metric.fund_id == fund_id]
+            leverage = temp_risk.first_repo_to_nav.values[0]
+            ptm = temp_risk.avg_ptm.values[0]
+        else:
+            leverage = np.nan
+            ptm = np.nan
+
+
+        
+        
 
         stock_tm_res = self._lambda_tm(df_i)
         stock_tm_alpha = stock_tm_res['alpha']
@@ -356,7 +442,7 @@ class FundIndicatorProcessorGroup:
         stock_cl_beta_p = stock_cl_res['beta_p']
 
         # stutzer
-        stutzer = self.stutzer_index(_ex_return)
+        stutzer = self.stutzer_index(df_i[:, 0]-self._RISK_FEE_RATE_PER_DAY) * np.sqrt(self._TRADING_DAYS_PER_YEAR)
         # stutzer = self.stutzer_index(np.array(self._fund_ret.tail(self._TRADING_DAYS_PER_YEAR)[fund_id] - self._benchmark_ret.tail(self._TRADING_DAYS_PER_YEAR)[fund_id]))
         return pd.Series({
             'fund_id':fund_id,
@@ -367,6 +453,14 @@ class FundIndicatorProcessorGroup:
             'annual_ret':annual_ret,
             'track_err':track_err,
             'mdd': mdd,
+            'mdd_len':mdd_len,
+            'winning_rate':winning_rate,
+            'VaR':VaR,
+            'CVaR':CVaR,
+            'ins_holds':ins_holds,
+            'hold_num':hold_num,
+            'leverage':leverage,
+            'ptm':ptm,
             'continue_regress_v':continue_regress_v,
             'continue_regress_t':continue_regress_t,
             'continue_stats_v':continue_stats_v,
@@ -392,6 +486,7 @@ class FundIndicatorProcessorGroup:
             'stock_hm_beta_t':stock_hm_beta_t,
             'stock_hm_beta_p':stock_hm_beta_p,
             'info_ratio':info_ratio,
+            'info_ratio_hs300':info_ratio_hs300,
             'treynor':treynor,
             'sharpe':sharpe,
             'calma_ratio':calma_ratio,
@@ -411,9 +506,17 @@ class FundIndicatorProcessorGroup:
             self.init(start_date, end_date)
             print('init done, to calc indicators')
             self.calculate()
+            #self._result.to_csv('result.csv')
             self._data_helper._upload_derived(self._result, FundIndicatorGroup.__table__.name)
         except Exception as e:
             print(e)
             traceback.print_exc()
             failed_tasks.append('fund_indicator_group')
         return failed_tasks
+
+if __name__ == '__main__':
+    from .derived_data_helper import DerivedDataHelper
+
+    date = '20200824'
+    fsg = FundIndicatorProcessorGroup(DerivedDataHelper())
+    fsg.process(date, date, pd.to_datetime(date).date())
