@@ -116,7 +116,11 @@ class EmRawDataDownloader:
         df = df.reset_index().rename(columns={
             'CODES': 'em_id',
             'DATES': 'datetime',
-            'CLOSE': 'close'
+            'CLOSE': 'close',
+            'OPEN': 'open',
+            'HIGH':'high',
+            'LOW':'low',
+            'VOLUME':'volume'
         })
         df = df[df['close'].notna()]
         self._data_helper._upload_raw(df, EmIndexPrice.__table__.name)
@@ -313,7 +317,7 @@ class EmRawDataDownloader:
                     continue
                 future_index.append(one)
             if future_index:
-                data = c.csd(','.join(future_index), "VOLUME,CLOSE", start_date, end_date, "period=1,adjustflag=1,curtype=1,order=1,market=CNSESH,Ispandas=1")
+                data = c.csd(','.join(future_index), "OPEN,HIGH,LOW,VOLUME,CLOSE", start_date, end_date, "period=1,adjustflag=1,curtype=1,order=1,market=CNSESH,Ispandas=1")
                 if not isinstance(data, pd.DataFrame):
                     if data.ErrorCode != 0:
                         print(f'[em_index_price] failed to get index price: {data.ErrorMsg} (index_id){future_index}')
@@ -321,7 +325,7 @@ class EmRawDataDownloader:
                 df_list.append(data)
 
             # 常规指数部分
-            data = c.csd(','.join(em_ids), "VOLUME,CLOSE", start_date, end_date, "period=1,adjustflag=1,curtype=1,order=1,market=CNSESH,Ispandas=1")
+            data = c.csd(','.join(em_ids), "OPEN,HIGH,LOW,VOLUME,CLOSE", start_date, end_date, "period=1,adjustflag=1,curtype=1,order=1,market=CNSESH,Ispandas=1")
             if not isinstance(data, pd.DataFrame):
                 if data.ErrorCode != 0:
                     print(f'[em_index_price] failed to get index price: {data.ErrorMsg} (index_id){em_ids}')
@@ -330,7 +334,11 @@ class EmRawDataDownloader:
             df = pd.concat(df_list + [data]).reset_index().rename(columns={
                 'CODES': 'em_id',
                 'DATES': 'datetime',
-                'CLOSE': 'close'
+                'CLOSE': 'close',
+                'OPEN': 'open',
+                'HIGH':'high',
+                'LOW':'low',
+                'VOLUME':'volume'
             })
             df = df[df['close'].notna()]
             # TODO: 最好可以原子提交下边两步操作
@@ -997,7 +1005,9 @@ class EmRawDataDownloader:
                 df = df[df.drop(columns='DATES').notna().any(axis=1)]
                 df = df.reset_index().rename(columns=lambda x: EmIndexVal.__getattribute__(EmIndexVal, x).name)
                 self._data_helper._upload_raw(df, EmIndexVal.__table__.name)
-            return True
+                return True
+            else:
+                return False
         except Exception as e:
             print(e)
             traceback.print_exc()
@@ -1278,8 +1288,11 @@ class EmRawDataDownloader:
 
         df = RawDataApi().get_em_tradedates(start_date, end_date)
         for row in df.itertuples(index=False):
-            self.em_fund_benchmark(row.TRADEDATES, fund_list_result.Codes)
-            print(f'[em_fund_benchmark_history] {row.TRADEDATES} done')
+            if self.em_fund_benchmark(row.TRADEDATES, fund_list_result.Codes):
+                print(f'[em_fund_benchmark_history] {row.TRADEDATES} done')
+            else:
+                print(f'[em_fund_benchmark_history] {row.TRADEDATES} failed')
+                break
 
     def em_fund_benchmark(self, end_date: str, fund_list):
         try:
@@ -1294,6 +1307,7 @@ class EmRawDataDownloader:
 
             df = data.reset_index().rename(columns=lambda x: EmFundBenchmark.__getattribute__(EmFundBenchmark, x).name)
             df['datetime'] = end_date
+            df['benchmark'] = df.benchmark.str.rstrip()
             # 获取当前的benchmark
             now_df = RawDataApi().get_em_fund_benchmark(end_date)
             if now_df is not None:
@@ -1625,7 +1639,7 @@ if __name__ == '__main__':
     # em.em_index_component('20200528', '20200529')
     # em.em_fund_list('20200702', '20200702')
     # em.em_fund_info_history('20200707')
-    # em.em_fund_benchmark_history('20100101', '20101231')
+    # em.em_fund_benchmark_history('20130320', '20131231')
     # em.em_index_info(['399972.SZ'])
     # em.em_fund_info({'165807.SZ'})
     # em.em_stock_estimate_fac('20200101', '20200709', 2020)
