@@ -1,10 +1,16 @@
 import pandas as pd
 import traceback
-from sqlalchemy import distinct
+import datetime
+from collections import Iterable
+from sqlalchemy import distinct, func
+from cassandra.cqlengine.query import BatchQuery
 from ...wrapper.mysql import DerivedDatabaseConnector, BasicDatabaseConnector, ViewDatabaseConnector
 from ...view.view_models import IndexDailyCollection
 from ...view.basic_models import IndexInfo, IndexPrice, IndexComponent
 from ...view.derived_models import IndexValuationLongTerm, IndexReturn, IndexVolatility
+from ....util.calculator import Calculator as SurfingCalculator
+from ...view.cas.tag_method_index_level import TagMethodIndexLevel
+from ....data.api.derived import DerivedDataApi
 
 class IndexDailyCollectionProcessor(object):
     def get_index_volatility(self):
@@ -125,9 +131,10 @@ class IndexDailyCollectionProcessor(object):
     def get_index_price(self):
         with BasicDatabaseConnector().managed_session() as mn_session:
             try:
-                latest_time = mn_session.query(IndexPrice).order_by(IndexPrice.datetime.desc()).limit(1).one_or_none()
-                latest_time = latest_time.datetime
-                print(latest_time)
+                subq = mn_session.query(
+                    IndexPrice.index_id.label('temp_id'),
+                    func.max(IndexPrice.datetime).label('temp_date'),
+                ).group_by(IndexPrice.index_id).subquery()
                 query = mn_session.query(
                     IndexPrice.index_id,
                     IndexPrice.datetime,
@@ -138,7 +145,10 @@ class IndexDailyCollectionProcessor(object):
                     IndexPrice.open,
                     IndexPrice.ret,
                     IndexPrice.total_turnover
-                ).filter(IndexPrice.datetime==latest_time)
+                ).filter(
+                    IndexPrice.index_id == subq.c.temp_id,
+                    IndexPrice.datetime == subq.c.temp_date
+                )
                 df = pd.read_sql(query.statement, query.session.bind)
                 df = df.rename(columns={'datetime': 'price_datetime'})
                 df = df.set_index('index_id')
@@ -147,6 +157,36 @@ class IndexDailyCollectionProcessor(object):
             except Exception as e:
                 print('Failed get_index_price<err_msg> {}'.format(e))
 
+    def calc_percentile(self, df):
+        def helper(x, temp_df, column):
+            temp_df = temp_df[temp_df['index_id'] == x]
+            ret = temp_df[column].quantile([0, .3, .7, 1])
+            return ret
+
+        start_date = datetime.datetime.now().date() - datetime.timedelta(days=3700)
+        with DerivedDatabaseConnector().managed_session() as mn_session:
+            query = mn_session.query(
+                IndexValuationLongTerm.pe_ttm,
+                IndexValuationLongTerm.pb_mrq,
+                IndexValuationLongTerm.index_id
+            ).filter(
+                IndexValuationLongTerm.datetime >= start_date,
+            )
+            pe_pb_df = pd.read_sql(query.statement, query.session.bind)
+
+        dff = df['index_id'].apply(helper, args=(pe_pb_df, 'pe_ttm',))
+        df['pe_0_percentile'] = dff[0.0]
+        df['pe_30_percentile'] = dff[0.3]
+        df['pe_70_percentile'] = dff[0.7]
+        df['pe_100_percentile'] = dff[1.0]
+
+        dff = df['index_id'].apply(helper, args=(pe_pb_df, 'pb_mrq',))
+        df['pb_0_percentile'] = dff[0.0]
+        df['pb_30_percentile'] = dff[0.3]
+        df['pb_70_percentile'] = dff[0.7]
+        df['pb_100_percentile'] = dff[1.0]
+        return df
+
     def get_index_yesterday_price(self):
         with BasicDatabaseConnector().managed_session() as mn_session:
             try:
@@ -171,6 +211,21 @@ class IndexDailyCollectionProcessor(object):
             except Exception as e:
                 print('Failed get_index_price<err_msg> {}'.format(e))
 
+    def index_level_save_to_cas(self, items):
+        groups = [i for i in range(0, len(items), 100)]
+        for i in groups:
+            if i != groups[-1]:
+                end = i + 100
+            else:
+                end = len(items)
+            for item in items[i: end]:
+                with BatchQuery() as batch:
+                    TagMethodIndexLevel.batch(batch).create(
+                        index_id=item.get('index_id'),
+                        data=item.get('data'),
+                        update_time=datetime.datetime.now(),
+                    )
+
     def append_data(self, table_name, data_append_directly_data_df):
         if not data_append_directly_data_df.empty:
             with ViewDatabaseConnector().managed_session() as mn_session:
@@ -184,6 +239,24 @@ class IndexDailyCollectionProcessor(object):
         else:
             print('没有需要插入的新数据')
 
+    def replace_datetime(self, obj):
+        if type(obj) == str:
+            return obj
+
+        if type(obj) == dict:
+            r = {}
+            for key in obj:
+                r[key] = self.replace_datetime(obj[key])
+            return r
+
+        if isinstance(obj, Iterable):
+            return list(map(lambda x: self.replace_datetime(x), obj))
+
+        if isinstance(obj, datetime.date):
+            return obj.strftime('%Y-%m-%d')
+
+        return obj
+
     def collection_daily_index(self):
         try:
             print('1、 load data...')
@@ -200,11 +273,29 @@ class IndexDailyCollectionProcessor(object):
             df.index.name = 'index_id'
             df = df.reset_index()
 
-            print('3、 special option...')
+            print('3、 calculate tag_method index level')
+            items = []
+            for i in df.index:
+                if not df.loc[i, 'tag_method']:
+                    d = []
+                else:
+                    d = SurfingCalculator().get_index_level_index_by_tag_method(
+                        df.loc[i, 'index_id'],
+                        df.loc[i, 'tag_method'],
+                    )
+                items.append({
+                    'index_id': df.loc[i, 'index_id'],
+                    'data': self.replace_datetime(d)
+                })
+
+            self.index_level_save_to_cas(items)
+
+            print('4、 special option...')
 
             df['order_book_id'] = df['em_id'].apply(lambda x: x.split('.')[0] if (x and x != 'not_available') else None)
             df = df.drop(['em_id'], axis=1)
             df['industry_tag'] = df['industry_tag'].apply(lambda x: x if x != 'not_available' else None)
+            df = self.calc_percentile(df)
 
             self.append_data(IndexDailyCollection.__tablename__, df)
 
