@@ -51,10 +51,11 @@ class AssetWeight(AssetDict):
         for k, v in self.__dict__.items():
             assert round(v,6) >= 0, f'{k} {v} has negative value'
             _sum += v
-        assert _sum > 0, 'param sum value must be positive'
+        assert _sum >= 0, 'param sum value must not be negative'
         # normalize, make sure change is correct
-        for k, v in self.__dict__.items():
-            self.__dict__[k] /= _sum
+        if _sum > 0:
+            for k, v in self.__dict__.items():
+                self.__dict__[k] /= _sum
     
     def __repr__(self):
         s = f'<{self.__class__.__name__}'
