@@ -115,7 +115,7 @@ class FundInfo(Base):
     __tablename__ = 'fund_info'
     fund_id = Column(CHAR(10), primary_key=True) # 基金ID
 
-    wind_id = Column(CHAR(20)) # Wind基金ID
+    wind_id = Column(CHAR(20), unique=True) # Wind基金ID
     transition = Column(Integer) # 基金变更次数
     order_book_id = Column(CHAR(10)) # RiceQuant基金ID
     desc_name = Column(CHAR(64)) # 基金名称
@@ -132,7 +132,7 @@ class FundInfo(Base):
     is_structured = Column(TINYINT(1)) # 是否为分级基金
     is_open = Column(TINYINT(1)) # 是否为日常开放申赎的基金 1是 0否， 排除掉封闭基金和定期开放基金
     is_regular_open_ended = Column(TINYINT(1)) # 是否为定期开放式基金 1是 0否
-    is_closed_ended= Column(TINYINT(1)) # 是否为封闭基金 1是 0 否
+    is_closed_ended = Column(TINYINT(1)) # 是否为封闭基金 1是 0 否
     structure_type = Column(TINYINT(1))  # 是否为分级子基金  0/nan非   1母   2分级A  3 分级B 4 其他
     is_etf = Column(TINYINT(1)) # 是否是etf  0 非  1 etf
     asset_type = Column(CHAR(32)) # 资产类别
@@ -146,9 +146,9 @@ class FundInfo(Base):
     benchmark_1 = Column(CHAR(255)) # 业绩基准标的指数简称第一名
     benchmark_2 = Column(CHAR(255)) # 业绩基准标的指数简称第二名
     index_id = Column(CHAR(20)) # 基于第一业绩标准所标注的指数ID
-    is_c =  Column("is_c", BOOLEAN, nullable=False)  #是否是etf  0 非  1 c
-    is_a = Column("is_a", BOOLEAN, nullable=False)  #是否是etf  0 非  1 a
-    ac_filter = Column("ac_filter", BOOLEAN, nullable=False) #是否ac均有要排除的a 0 排除  1 保留
+    is_c =  Column("is_c", BOOLEAN)  #是否是etf  0 非  1 c
+    is_a = Column("is_a", BOOLEAN)  #是否是etf  0 非  1 a
+    ac_filter = Column("ac_filter", BOOLEAN) #是否ac均有要排除的a 0 排除  1 保留
     is_selected_mmf = Column(TINYINT(1)) # 是否基金规模最大的前50只货币基金(10年前有两只存在)  0 非  1 是
     national_debt_extension = Column(TINYINT(1)) # 纯债tag  0 非  1 是
     index_id_new = Column(CHAR(20)) # 基于第一业绩标准所标注的指数ID新
@@ -529,7 +529,11 @@ class MngInfo(Base):
     education = Column(CHAR(4)) # 学历
     nationality =  Column(CHAR(10)) # 国籍
     resume = Column(TEXT) # 简历
-    
+
+    __table_args__ = (
+        Index('idx_mng_info_fund_id', 'fund_id'),
+    )
+
 class FundMngChange(Base):
     '''基金经理变更表'''
 
@@ -585,4 +589,4 @@ class FundCompCoreMng(Base):
     com_core_mng_resign_num = Column(DOUBLE(asdecimal=False)) #基金公司核心人员离职人数
     com_core_mng_resign_rate = 	Column(DOUBLE(asdecimal=False)) #基金公司核心人员离职率(%)
     fund_type = Column(CHAR(25)) # 基金类型
-    region = Column(CHAR(5)) # 监管辖区
\ No newline at end of file
+    region = Column(CHAR(5)) # 监管辖区
