@@ -101,10 +101,16 @@ class IndexValuationLongTerm(Base):
     peg_ttm = Column(DOUBLE(asdecimal=False)) # 市盈率相对盈利增长比率-MMT
     pe_pct = Column(DOUBLE(asdecimal=False)) # PE百分位(10/5年)
     pb_pct = Column(DOUBLE(asdecimal=False)) # PB百分位(10/5年)
-    ps_pct = Column(DOUBLE(asdecimal=False)) # PS百分位(10/5年)
+    roe_pct = Column(DOUBLE(asdecimal=False)) # ROE百分位(10/5年)
+    pe_pct_30 = Column(DOUBLE(asdecimal=False)) # PE百分位(10/5年) 30 分位
+    pe_pct_70 = Column(DOUBLE(asdecimal=False)) # PE百分位(10/5年) 70 分位
+    pb_pct_30 = Column(DOUBLE(asdecimal=False)) # PB百分位(10/5年) 30 分位
+    pb_pct_70 = Column(DOUBLE(asdecimal=False)) # PB百分位(10/5年) 70 分位
+    roe_pct_30 = Column(DOUBLE(asdecimal=False)) # ROE百分位(10/5年) 30 分位
+    roe_pct_70 = Column(DOUBLE(asdecimal=False)) # ROE百分位(10/5年) 70 分位
     val_score = Column(DOUBLE(asdecimal=False)) # 估值评分(10/5年)
     eps_ttm = Column(DOUBLE(asdecimal=False)) # 每股收益—MMT
-    roe_pct = Column(DOUBLE(asdecimal=False)) # ROE百分位(10/5年)
+    ps_pct = Column(DOUBLE(asdecimal=False)) # PS百分位(10/5年)
     est_peg = Column(DOUBLE(asdecimal=False)) # 预测peg
     pe_pct_5_3 = Column(DOUBLE(asdecimal=False)) # PE百分位
     pb_pct_5_3 = Column(DOUBLE(asdecimal=False)) # PB百分位
@@ -208,8 +214,17 @@ class FundIndicatorGroup(Base):
     alpha = Column(DOUBLE(asdecimal=False))
     track_err = Column(DOUBLE(asdecimal=False))  # 跟踪误差
     info_ratio = Column(DOUBLE(asdecimal=False))  # 信息比率
+    info_ratio_hs300 = Column(DOUBLE(asdecimal=False))  # 相对沪深300的信息比率
     treynor = Column(DOUBLE(asdecimal=False))  # 特雷诺比率
     mdd = Column(DOUBLE(asdecimal=False))  # 净值最大回撤
+    mdd_len = Column(DOUBLE(asdecimal=False))  # 最大回撤持续时间
+    winning_rate = Column(DOUBLE(asdecimal=False))  # 和mmf的相对胜率
+    VaR = Column(DOUBLE(asdecimal=False))  # Value at Risk
+    CVaR = Column(DOUBLE(asdecimal=False))  # Expected Shortfall
+    ins_holds = Column(DOUBLE(asdecimal=False))  # 机构持有者占比
+    hold_num = Column(DOUBLE(asdecimal=False))  # 持有人数量
+    leverage = Column(DOUBLE(asdecimal=False))  # 杠杆
+    ptm = Column(DOUBLE(asdecimal=False))  # 到期期限
     annual_vol = Column(DOUBLE(asdecimal=False))  # 年化波动率
     annual_ret = Column(DOUBLE(asdecimal=False))  # 年化收益
     sharpe = Column(DOUBLE(asdecimal=False))
@@ -422,4 +437,44 @@ class StyleReg(Base):
     mid_v = Column(DOUBLE(asdecimal=False))
     small_g = Column(DOUBLE(asdecimal=False))
     small_v = Column(DOUBLE(asdecimal=False))
-   
+
+
+class FundManagerIndex(Base):
+    '''基金经理指数'''
+
+    __tablename__ = 'fund_manager_index'
+
+    manager_id = Column(CHAR(16), primary_key=True)  # 基金经理ID
+    datetime = Column(DATE, primary_key=True)  # 日期
+    fund_type = Column(CHAR(8), primary_key=True)  # 所管理基金类型
+    manager_index = Column(DOUBLE(asdecimal=False))  # 基金经理指数
+
+class FundManagerScore(Base):
+    '''基金经理评分以及因子'''
+
+    __tablename__ = 'fund_manager_score'
+
+    manager_id = Column(CHAR(16), primary_key=True)  # 基金经理ID
+    datetime = Column(DATE, primary_key=True)  # 日期
+    fund_type = Column(CHAR(8), primary_key=True)  # 所管理基金类型
+    start_date = Column(DATE)
+    trade_year = Column(DOUBLE(asdecimal=False))
+    last_unit_nav = Column(DOUBLE(asdecimal=False))
+    annualized_ret = Column(DOUBLE(asdecimal=False))
+    annualized_vol = Column(DOUBLE(asdecimal=False))
+    sharpe = Column(DOUBLE(asdecimal=False))
+    recent_y5_ret = Column(DOUBLE(asdecimal=False))
+    mdd = Column(DOUBLE(asdecimal=False))
+    mdd_date1 = Column(DOUBLE(asdecimal=False))
+    mdd_date2 = Column(DOUBLE(asdecimal=False))
+    ret_over_mdd = Column(DOUBLE(asdecimal=False))
+    last_mv_diff = Column(DOUBLE(asdecimal=False))
+    last_increase_rate = Column(DOUBLE(asdecimal=False))
+    alpha = Column(DOUBLE(asdecimal=False))
+    beta = Column(DOUBLE(asdecimal=False))
+    track_err = Column(DOUBLE(asdecimal=False))
+    ir = Column(DOUBLE(asdecimal=False))
+    model_alpha = Column(DOUBLE(asdecimal=False))
+    model_beta = Column(DOUBLE(asdecimal=False))
+    score = Column(DOUBLE(asdecimal=False))
+
