@@ -279,6 +279,9 @@ class EmIndexPrice(Base):
     __tablename__ = 'em_index_price'
     em_id = Column(CHAR(20), primary_key=True) # Choice代码
     datetime = Column(DATE, primary_key=True) # 日期
+    open = Column(DOUBLE(asdecimal=False)) # 开盘价
+    high = Column(DOUBLE(asdecimal=False)) # 最高价
+    low = Column(DOUBLE(asdecimal=False)) # 最低价
     close = Column(DOUBLE(asdecimal=False)) # 收盘价
     volume = Column(DOUBLE(asdecimal=False)) # 交易量
 
@@ -590,13 +593,13 @@ class EmStockInfo(Base):
     FINSELLORNOT = Column("fin_sell_ornot", BOOLEAN, nullable=False) # 是否属于融券标的
     STOHSTOCKCONNECTEDORNOT = Column("stoh_stock_connected_ornot", BOOLEAN, nullable=False) # 是否属于沪股通标的
     SHENGUTONGTARGET = Column("shengutong_target", BOOLEAN, nullable=False) # 是否属于深股通标的
-    BLEMINDCODE = Column("bl_em_ind_code", CHAR(40), nullable=False) # 所属东财行业指数代码
+    BLEMINDCODE = Column("bl_em_ind_code", CHAR(40)) # 所属东财行业指数代码
     BLSWSINDCODE = Column("bl_sws_ind_code", CHAR(40), nullable=False) # 所属申万行业指数代码
     SW2014CODE = Column("sw_2014_code", CHAR(40), nullable=False) # 所属申万行业代码
     EMINDCODE2016 = Column("em_ind_code_2016", CHAR(40), nullable=False) # 所属东财行业(2016)代码
     CITICCODE2020 = Column("citic_code_2020", CHAR(40)) # 所属中信行业代码(2020)
-    BLCSRCINDCODE = Column("bl_csrc_ind_code", CHAR(32), nullable=False) # 所属证监会行业指数代码
-    CSRCCODENEW = Column("csrc_code_new", CHAR(16), nullable=False) # 所属证监会行业(新)代码
+    BLCSRCINDCODE = Column("bl_csrc_ind_code", CHAR(32)) # 所属证监会行业指数代码
+    CSRCCODENEW = Column("csrc_code_new", CHAR(16)) # 所属证监会行业(新)代码
     CSINDCODE2016 = Column("cs_ind_code_2016", CHAR(32), nullable=False) # 所属中证行业(2016)代码
     GICSCODE = Column("gics_code", CHAR(32), nullable=False) # 所属GICS行业代码
 
@@ -829,7 +832,7 @@ class EmFundBenchmark(Base):
 
     CODES = Column('em_id', CHAR(16), primary_key=True) # 基金代码
     DATES = Column('datetime', DATE, primary_key=True) # 日期
-    BENCHMARK = Column('benchmark', CHAR(255), nullable=False) # 业绩比较基准
+    BENCHMARK = Column('benchmark', TEXT, nullable=False) # 业绩比较基准
 
     __table_args__ = (
         Index('idx_em_fund_benchmark_datetime', 'datetime'),
@@ -894,6 +897,19 @@ class WindFundStockPortfolio(Base):
     STOCK_PER = Column(DOUBLE(asdecimal=False)) # 占股票市值比
     FLOAT_SHR_PER = Column(DOUBLE(asdecimal=False)) # 占流通股本比例
 
+class WindFundBondPortfolio(Base):
+    '''万德静态数据 中国共同基金投资组合 持债明细'''
+
+    __tablename__ = 'wind_fund_bond_portfolio'
+
+    F_PRT_ENDDATE = Column(DATE, primary_key=True)  # 日期
+    S_INFO_WINDCODE = Column(CHAR(16), primary_key=True)  # wind基金id
+    S_INFO_BONDWINDCODE = Column(CHAR(16), primary_key=True)  # wind债券id
+    CRNCY_CODE = Column(CHAR(5))  # 货币类型
+    F_PRT_BDVALUE = Column(DOUBLE(asdecimal=False)) # 持有债券市值
+    F_PRT_BDQUANTITY = Column(DOUBLE(asdecimal=False)) # 持有债券数量
+    F_PRT_BDVALUETONAV = Column(DOUBLE(asdecimal=False)) # 持有债券市值占基金净值比例
+
 class WindFundNav(Base):
     '''万德静态数据 中国共同基金净值'''
 
@@ -1174,6 +1190,10 @@ class EMMngInfo(Base):
     nationality =  Column(CHAR(10)) # 国籍
     resume = Column(TEXT) # 简历
 
+    __table_args__ = (
+        Index('idx_em_mng_info_code', 'code'),
+    )
+
 class EMFundMngChange(Base):
     '''东财基金经理变更表'''
 
@@ -1231,6 +1251,19 @@ class EMFundCompCoreMng(Base):
     fund_type = Column(CHAR(25)) # 基金类型
     region = Column(CHAR(5)) # 监管辖区
 
+class EmBondInfo(Base):
+    '''Choice债券信息'''
+
+    __tablename__ = 'em_bond_info'
+
+    CODES = Column('bond_id', CHAR(16), primary_key=True) # EM债券ID
+    NAME = Column("name", TEXT, nullable=False) # 债券名称
+    CORPCODE = Column('corp_code', CHAR(32)) # 公司债对应上市公司代码
+    EM1TYPE = Column('em1_type', CHAR(12)) # 东财债券一级分类
+    EM2TYPE = Column('em2_type', CHAR(12)) # 东财债券二级分类
+    CBL1TYPE = Column('cbl1_type', CHAR(16)) # 中债债券一级分类
+    CBL2TYPE = Column('cbl2_type', CHAR(16)) # 中债债券二级分类
+
 class EmBondRating(Base):
     '''Choice债券评级'''
 
