@@ -233,6 +233,15 @@ class IndexDailyCollection(Base):
     ps_pct = Column(DOUBLE(asdecimal=False))  # PS百分位
     val_score = Column(DOUBLE(asdecimal=False))  # 估值评分
 
+    pe_0_percentile = Column(DOUBLE(asdecimal=False))  # pe0分位
+    pe_30_percentile = Column(DOUBLE(asdecimal=False))  # pe30分位
+    pe_70_percentile = Column(DOUBLE(asdecimal=False))  # pe70分位
+    pe_100_percentile = Column(DOUBLE(asdecimal=False))  # pe100分位
+    pb_0_percentile = Column(DOUBLE(asdecimal=False))  # pb0分位
+    pb_30_percentile = Column(DOUBLE(asdecimal=False))  # pb30分位
+    pb_70_percentile = Column(DOUBLE(asdecimal=False))  # pb70分位
+    pb_100_percentile = Column(DOUBLE(asdecimal=False))  # pb100分位
+
     vol_datetime = Column(DATE)  # 日期
     w1_vol = Column(DOUBLE(asdecimal=False))  # 近一周波动率
     m1_vol = Column(DOUBLE(asdecimal=False))  # 近一月波动率
@@ -313,6 +322,15 @@ class IndexDailyCollection(Base):
             'val_score': '估值评分',
             'alpha_datetime': 'alpha日期',
 
+            'pe_0_percentile': 'pe0分位',
+            'pe_30_percentile': 'pe30分位',
+            'pe_70_percentile': 'pe70分位',
+            'pe_100_percentile': 'pe100分位',
+            'pb_0_percentile': 'pb0分位',
+            'pb_30_percentile': 'pb30分位',
+            'pb_70_percentile': 'pb70分位',
+            'pb_100_percentile': 'pb100分位',
+
             'price_datetime': '价格日期',
             'volume': '交易量',
             'low': '最低价',
