@@ -138,7 +138,7 @@ class ReportHelper:
 
     def _calc_stat(self, df):
         res = Calculator.get_stat_result_from_df(df=df.reset_index(), date_column='date', value_column='mv')
-        w = copy.deepcopy(self.saa_weight) if self.saa_weight else AssetWeight(hs300=1.0).__dict__ # asset weight float
+        w = copy.deepcopy(self.saa_weight) if self.saa_weight else AssetWeight().__dict__ # asset weight float
         self._calc_stat_yearly(df)
         w['mdd'] = res.mdd #float
         w['annual_ret'] = res.annualized_ret #float
@@ -187,6 +187,9 @@ class ReportHelper:
             f.write(json.dumps(dic, cls=DatetimeEncoder))
 
     def get_fund_stat(self):
+        if not self.fund_marktet_price_history:
+            return None
+            
         self.fund_mv = pd.DataFrame([ {'date':k, 'mv':v} for k,v in self.fund_marktet_price_history.items()]).set_index('date')
         w = self._calc_stat(self.fund_mv.copy())
         return w
@@ -250,8 +253,16 @@ class ReportHelper:
             ft['before_w']  = self.fund_weights_history[submit_d].get(fund_id,0)
             ft['after_w'] = self.fund_weights_history[traded_d].get(fund_id,0)
             ft_res.append(ft)
-        fund_trade_df = pd.DataFrame(ft_res)
-        return fund_trade_df
+        df = pd.DataFrame(ft_res)
+        df['before_w'] = df['before_w'].round(4)
+        df['after_w'] = df['after_w'].round(4)
+        dts = df.submit_date.unique().tolist()
+        for dt in dts:
+            _df = df[df['submit_date'] == dt]
+            fund_id = _df.iloc[-1].fund_id
+            df.loc[(df['submit_date'] == dt) & (df['fund_id'] == fund_id),'after_w'] = 1 - _df.iloc[:-1].after_w.sum()
+            df.loc[(df['submit_date'] == dt) & (df['fund_id'] == fund_id),'before_w'] = 1 - _df.iloc[:-1].before_w.sum()
+        return df
 
     @staticmethod
     def fund_rank_recent_analysis(dm, fund_id):
@@ -277,7 +288,16 @@ class ReportHelper:
             dic['before_w'] = self.asset_weights_history[submit_d].get(index_id, 0)
             dic['after_w'] = self.asset_weights_history[traded_d].get(index_id, 0)
             res.append(dic)
-        return pd.DataFrame(res)
+        df = pd.DataFrame(res)
+        df['before_w'] = df['before_w'].round(4)
+        df['after_w'] = df['after_w'].round(4)
+        dts = df.submit_date.unique().tolist()
+        for dt in dts:
+            _df = df[df['submit_date'] == dt]
+            index_id = _df.iloc[-1].index_id
+            df.loc[(df['submit_date'] == dt) & (df['index_id'] == index_id),'after_w'] = 1 - _df.iloc[:-1].after_w.sum()
+            df.loc[(df['submit_date'] == dt) & (df['index_id'] == index_id),'before_w'] = 1 - _df.iloc[:-1].before_w.sum()
+        return df
 
     def get_fund_position(self):
         fund_pos = []
