@@ -592,13 +592,15 @@ class BasicFundTrader(Helper):
                         submit_date=dt
                     )
                 else:
+                    is_to_clean_up = target_fund_amt == 0 and cur_fund_amt > 0
                     _trade = FundTrade(
                         fund_id=fund_id,
                         index_id=index_id,
                         mark_price=p,
                         volume=abs(target_fund_amt - cur_fund_amt)/p,
                         is_buy=is_buy,
-                        submit_date=dt
+                        submit_date=dt,
+                        is_to_cleanup=is_to_clean_up
                     )
                 fund_trades.append(_trade)
                 #print(f'(fund){fund_id} (p){p} (amt0){cur_fund_amt} (amt1){target_fund_amt} (idx){index_id} (amt){abs(target_fund_amt - cur_fund_amt)} (direc) {target_fund_amt > cur_fund_amt} ')
