@@ -77,8 +77,8 @@ class Calculator:
             last_increase_rate = (sr[-1] - sr[-2])/ sr[-2]
         # 如果只输入一天，返回空
         else:
-            start_date = dates[0]
-            end_date = dates[0]
+            start_date = dates[0] if len(dates) > 0 else None
+            end_date = dates[0] if len(dates) > 0 else None
             trade_year = 0
             last_unit_nav = 1
             annualized_ret = 0
@@ -86,8 +86,8 @@ class Calculator:
             sharpe = 0 
             recent_y5_ret = 0
             mdd = 0
-            mdd_date1 = dates[0]
-            mdd_date2 = dates[0]
+            mdd_date1 = dates[0] if len(dates) > 0 else None
+            mdd_date2 = dates[0] if len(dates) > 0 else None
             ret_over_mdd = 0
             last_mv_diff = 0
             last_increase_rate = 0
@@ -219,8 +219,8 @@ class Calculator:
     @staticmethod
     def get_index_pct_data_df(index_id:str='hs300',
                            index_val:str=None,
-                           windows:int=5*242,
-                           min_periods:int=3*242,
+                           windows:int=10*242,
+                           min_periods:int=5*242,
                            pct_list:list=[0.15, 0.5, 0.6, 0.8]):
         
         assert (index_id in list(TaaTunerParam.PCT_PAIR.keys())) or (index_val is not None), \
@@ -366,6 +366,54 @@ class Calculator:
         res = [i for i in res if i['val_level'] != 'median']
         return res
 
+    @staticmethod
+    def get_index_level_index_by_tag_method(index_id: str, tag_method: str):
+        val_dict = {
+            'PB百分位': IndexValuationLongTerm.pb_pct,
+            'PE百分位': IndexValuationLongTerm.pe_pct,
+            'PS百分位': IndexValuationLongTerm.ps_pct,
+        }
+
+        with DerivedDatabaseConnector().managed_session() as mn_session:
+            query = mn_session.query(
+                IndexValuationLongTerm.pe_ttm,
+                IndexValuationLongTerm.datetime,
+                val_dict.get(tag_method),
+            ).filter(
+                IndexValuationLongTerm.index_id.in_([index_id]),
+            )
+            index_val_df = pandas.read_sql(query.statement, query.session.bind)
+        index_val_df['tag_method'] = tag_method
+        if len(index_val_df) < 1:
+            return []
+        index_val_df['val_level'] = index_val_df.apply(lambda x: Calculator.get_val_level(x), axis=1)
+        index_val = index_val_df[['datetime', 'val_level']]
+        index_val = index_val.dropna(how='any')
+        if len(index_val) < 1:
+            return []
+        res = []
+        last_level = 'begin'
+        dic = {}
+        for i in index_val.itertuples():
+            if i.val_level != last_level and not dic:
+                dic.update({'start_date': i.datetime})
+                dic.update({'val_level': i.val_level})
+                last_level = i.val_level
+
+            elif i.val_level != last_level and dic:
+                dic.update({'end_date': last_date})
+                last_level = i.val_level
+                res.append(dic)
+                dic = {}
+                dic.update({'start_date': i.datetime})
+                dic.update({'val_level': i.val_level})
+            last_date = i.datetime
+        if 'end_date' not in dic:
+            dic.update({'end_date': last_date})
+        res.append(dic)
+        res = [i for i in res if i['val_level'] != 'median']
+        return res
+
     @staticmethod
     def get_mdd_recover_result(mv_df:pandas.DataFrame):
 
